#-------------------------------------------------------------------------------
#
#   Mutagenesis - Shell
#
#-------------------------------------------------------------------------------

from albow.controls import Button
from albow.layout import Row, Column
from albow.resource import get_image
from albow.references import Ref
from humerus.hshell import HShell
from humerus.main_commands import MainCommandScreen
from plant_view import PlantView
from catalog_view import CatalogView
from controls import MGButton
from game import game

class MainMenuScreen(MainCommandScreen):

	def __init__(self, shell):
		MainCommandScreen.__init__(self, shell, with_menu = True)

#-------------------------------------------------------------------------------

grow_image = get_image("watering_can.png", border = 2)
mutate_image = get_image("radiation.png", border = 2)
single_image = get_image("single_view.png", border = 2)
split_image = get_image("split_view.png", border = 2)
breed_image = get_image("bee.png", border = 2)
trash_image = get_image("wheelie_bin.png", border = 2)

class PlayScreen(MainCommandScreen):

	split_view_mode = False

	def __init__(self, shell):
		MainCommandScreen.__init__(self, shell)
		grow_btn = MGButton(image = grow_image,
			action = game.restart_growth,
			enable = self.have_plant)
		mutate_btn = MGButton(image = mutate_image,
			action = self.mutate,
			enable = self.have_plant)
		single_button = MGButton(image = single_image,
			action = self.single_view)
		split_button = MGButton(image = split_image,
			action = self.split_view)
		breed_button = MGButton(image = breed_image,
			action = game.breed,
			enable = self.breeding_enabled)
		trash_button = MGButton(image = trash_image,
			action = game.discard_current_specimen,
			enable = self.trash_enabled)
		controls = Row([grow_btn, mutate_btn, single_button, split_button,
			breed_button, trash_button], spacing = 5)
		catalog_view = CatalogView(anchor = 'tb')
		self.plant_view = PlantView(height = catalog_view.height, anchor = 'tb',
			ref = Ref(game).current_specimen)
		views = Row([self.plant_view, catalog_view], expand = 0)
		views.width = self.width
		contents = Column([views, controls],
			align = 'l', expand = 0, margin = 2, spacing = 2)
		contents.height = self.height
		size = ((self.plant_view.width - 2) // 2, self.plant_view.height)
		plant1_view = PlantView(size = size, ref = Ref(game).last_specimen)
		plant2_view = PlantView(size = size, ref = Ref(game).current_specimen)
		self.dual_view = Row([plant1_view, plant2_view],
			spacing = 2, visible = False)
		self.dual_view.topleft = self.plant_view.topleft
		views.add(self.dual_view)
		self.add(contents)
	
	def growth_step(self):
		game.current_specimen.growth_step()
	
	def mutate(self):
		game.mutate_current_specimen()
	
	def single_view(self):
		self.split_view_mode = False
		self.dual_view.visible = False
		self.plant_view.visible = True
	
	def split_view(self):
		self.split_view_mode = True
		self.dual_view.visible = True
		self.plant_view.visible = False
	
	def have_plant(self):
		return game.current_specimen

	def breeding_enabled(self):
		return self.split_view_mode and game.last_specimen
	
	def trash_enabled(self):
		plant = game.current_specimen
		return plant and plant.number <> 1

#-------------------------------------------------------------------------------

class Shell(HShell):

	game_title = "Mutagenesis"

	def __init__(self, game, options):
		HShell.__init__(self, game, options)
		self.main_menu_screen = MainMenuScreen(self)
		self.play_screen = PlayScreen(self)
		game.init_timing()
